<?php
/**
 * A custom WordPress nav walker class for Bootstrap 5 nav menus.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

class WP_Walker_Nav_Menu extends Walker_Nav_menu {
  private $current_item;
  private $dropdown_menu_alignment_values = [
    'submenu-left'
  ];

  /**
   * Responsible for organizing the placement of items.
   * 
   * @package Gomax
   * @since 1.0.0
   */
  function start_lvl( & $output, $depth = 0, $args = null ) {
    $dropdown_menu_class[] = '';

    foreach( $this->current_item->classes as $class ) {			
      if ( in_array( $class, $this->dropdown_menu_alignment_values ) ) {
        $dropdown_menu_class[] = $class;
      }
    }

    $indent  = str_repeat( "\t", $depth );
    $submenu = ( $depth > 0 ) ? ' submenu' : '';
    $output .= "\n$indent<ul class=\"dropdown-menu animate fade-down$submenu " . esc_attr( implode( " ", $dropdown_menu_class ) ) . " depth_$depth\">\n";
  }

  /**
   * Responsible for displaying custom elements.
   * 
   * @package Gomax
   * @since 1.0.0
   */
  function start_el( & $output, $item, $depth = 0, $args = null, $id = 0 ) {
    $this->current_item = $item;

    $indent        = ( $depth ) ? str_repeat( "\t", $depth ) : '';
    $li_attributes = '';
    $class_names   = $value = '';

    $classes = empty( $item->classes ) ? array() : ( array ) $item->classes;

    $classes[] = ( $args->walker->has_children ) ? 'dropdown hover' : '';
    $classes[] = 'nav-item';
    $classes[] = 'nav-item-' . $item->ID;

    if ( $depth && $args->walker->has_children ) {
      $classes[] = 'dropdown hover';
    }

    $class_names           = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
    $has_megamenu          = strpos( $class_names, 'has-megamenu' ) !== false;
    $has_language_switcher = strpos( $class_names, 'language-switcher' ) !== false;
    $has_currency_switcher = strpos( $class_names, 'currency-switcher' ) !== false;
    $is_polylang           = strpos( $class_names, 'pll-parent-menu-item' ) !== false;

    if ( $has_megamenu ) {
      $class_names .= ' dropdown hover';
    }

    $class_names = ' class="' . esc_attr( $class_names ) . '"';

    $id = apply_filters( 'nav_menu_item_id', 'menu-item-' . $item->ID, $item, $args );
    $id = strlen( $id ) ? ' id="' . esc_attr( $id ) . '"' : '';

    $output .= $indent . '<li ' . $id . $value . $class_names . $li_attributes . '>';

    $attributes  = ! empty( $item->attr_title ) ? ' title="' . esc_attr( $item->attr_title ) . '"' : '';
    $attributes .= ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) . '"' : '';
    $attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) . '"' : '';
    $attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) . '"' : '';

    $active_class   = ( $item->current || $item->current_item_ancestor || in_array( "current_page_parent", $item->classes, true ) || in_array( "current-post-ancestor", $item->classes, true ) ) ? ' active' : '';
    $nav_link_class = 'nav-link';
    $attributes    .= ( $args->walker->has_children || $has_megamenu ) ? ' class="'. $nav_link_class . $active_class . ' dropdown-toggle has-icon" data-bs-toggle="dropdown"' : ' class="'. $nav_link_class . $active_class . '"';

    $item_output  = $args->before;
    $item_output .= '<a' . $attributes . '>';

    if ( gomax_has_core() && gomax_has_elementor() ) {

      if ( $has_language_switcher ) {
        $item_output .= themeasy_get_svg_icon( 'feather', 'globe' );
      }

      if ( $has_currency_switcher ) {
        $item_output .= themeasy_get_svg_icon( 'feather', 'dollar-sign' );
      }

      // Polylang plugin.
      $globe_icon = themeasy_get_svg_icon( 'feather', 'user', 'language-switcher-icon' );
      $item_output .= ( $args->walker->has_children && $is_polylang ) ? $globe_icon : '';
    }

    $item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;

    if ( gomax_has_core() && gomax_has_elementor() ) {
      $dropdown_icon = themeasy_get_svg_icon( 'feather', 'chevron-down', 'icon dropdown-icon' );
		  $item_output .= ( $depth == 0 && $args->walker->has_children || $has_megamenu ) ? $dropdown_icon : '';
    }
    
    $item_output .= '</a>';

    /**
     * Display the contents of the megamenu below the menu item.
     * 
     * @package Gomax
     * @since 1.0.0
     */
    if ( $has_megamenu ) {
      $post_id   = get_post_meta( $item->ID, '_themeasy_megamenu', true );
      $post_item = get_post( $post_id );

      // Check if it exist
      if ( $post_id && $post_item ) {

        // Add content
        if ( gomax_has_core() && gomax_has_elementor() ) {

          $item_output .= '<div class="dropdown-menu megamenu megamenu-'. $post_id . ' animate fade-down">';
          $item_output .= '<div class="container">';
          $item_output .= '<div class="inner-section-expanded">';
          
          $frontend     = new \Elementor\Frontend();
          $item_output .= $frontend->get_builder_content_for_display( $post_id, $with_css = false );

          $item_output .= '</div></div></div>';
        }
      }
    }    

    $item_output .= $args->after;
    $output      .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
  }
}