<?php
/**
 * Set of theme general utility functions.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

/**
 * Check the WordPress version.
 * 
 * @package Gomax
 * @since 1.0.0
 */
if ( ! function_exists( 'wp_version' ) ) {
	function wp_version() {
		global $wp_version;
		return $wp_version;
	}
}

/**
 * Check the theme version.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_get_theme_version() {
	return wp_get_theme('gomax')->get( 'Version' );
}

/**
 * Checks if the main theme plugin is installed and active.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_has_core() {
	if ( function_exists( 'themeasy_init' ) ) {
		return true;
	}
}

/**
 * Checks if the Elementor plugin is installed and active.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_has_elementor() {
	if ( did_action( 'elementor/loaded' ) ) {
		return true;
	}
}

/**
 * Checks if the WooCommerce plugin is installed and active.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_has_woocommerce() {
	if ( class_exists( 'WooCommerce' ) ) {
		return true;
	}
}

/**
 * Checks if the required plugin is installed and active.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_has_plugins() {
	$core      = function_exists( 'themeasy_init' );
	$elementor = did_action( 'elementor/loaded' );
	$cf7       = class_exists( 'WPCF7' );

	if ( $core && $elementor && $cf7 ) {
		return true;
	}
}

/**
 * Check if the theme is licensed.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_has_licence() {
	$dashboard = admin_url( '/admin.php?page=gomax-dashboard' );

	if ( get_option( 'gomax_licence_key' ) ) {
		return true;

	} else {

		if ( isset( $_GET['page'] ) && $_GET['page'] === 'one-click-demo-import' ) {
			wp_redirect( $dashboard );
		}
	}
}
add_action( 'admin_init', 'gomax_has_licence', 99 );

/**
 * Check if the content is empty.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_is_empty_content( $str ) {
	return trim( str_replace( '&nbsp;', '', strip_tags( $str, '<img>' ) ) ) == '';
}

/**
 * Check the title of the page and according to the type.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_get_page_title() {

	// Single post
	if ( is_single() || is_page() ) {
		$page_title = get_the_title();	
	}
	
	// Archive
	elseif ( is_archive() || is_category() || is_tag() || is_date() || is_author() ) {
		$page_title = get_the_archive_title();
	}

	// Search page
	elseif ( is_search() ) {
		$page_title = __( 'Search Page', 'gomax' );
	}

	// 404 page
	elseif ( is_404() ) {
		$page_title = __( '404 Error', 'gomax' );	
	}

	// None
	else {
		$page_title =  '';
	}

 	return $page_title;
}

/**
 * Get the formatted date of a post in elapsed time.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_get_time_ago() {
	return human_time_diff( get_the_time( 'U' ), current_time( 'timestamp' ) ) . __( ' ago', 'gomax' );
}

/**
 * Get the author's avatar image.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_get_author_image() {
	$author_id = get_the_author_meta( 'ID' );
	$output    = get_avatar_url( $author_id );
	return $output;
}

/**
 * Get the count of comments on a post.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_get_comment_count() {
	$number = get_comments_number();

	if ( $number > 0 && $number != 1 ) {
		return $number . __( ' Comments', 'gomax' );

	} elseif ( $number == 1 ) {
		return $number . __( ' Comment', 'gomax' );

	} else {
		return __( 'Leave a comment', 'gomax' );
	}
}