<?php
/**
 * Apply support functions.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

/**
 * Notifies that the plugin WooCommerce only works properly with the Themeasy.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_admin_notice_missing_core() {
  printf( 
    '<div class="gomax-theme-notice notice not-dismissible"><p>%s</p>%s</div>', 
    sprintf(
      /* translators: %1$s and %2$s - <em> HTML tags, %3$s - link */
      __( 'Please activate the %1$sThemeasy%2$s plugin if you intend to use %1$sWooCommerce%2$s with %1$sGomax Theme%2$s.', 'gomax' ),
      '<em>', '</em>'
    ),
    sprintf(
      /* translators: %1$s - link, %2$s - icon */
      '<a href="%1$s" target="_blank" class="link">%2$s</a>',
      'https://themeasy.co/help/required-plugins',
      sprintf(
        /* translators: %1$s - text */
        '<span class="dashicons dashicons-editor-help icon"></span>%1$s',
        __( 'Get Help', 'gomax' )
      )
    )
  );
}

// Show notification if WooCommerce is enabled and Themeasy is deactivated.
if ( ! gomax_has_core() && gomax_has_woocommerce() ) {
	add_action( 'admin_notices', 'gomax_admin_notice_missing_core' );
}

/**
 * Allows to change and allow external requests for the HTTP request.
 * 
 * @package Gomax
 * @since 1.0.0
 */
if ( get_theme_mod( 'enable_external_http_request' ) ) {
	add_filter( 'http_request_host_is_external', '__return_true' );
}

/**
 * Disables SSL verification for requests to specific URL.
 * 
 * This filter modifies HTTP request arguments to bypass SSL verification 
 * when connecting to 'package.themeasy.co'. It is useful for handling cases 
 * where SSL certificate issues might prevent successful communication 
 * with this server. Note: Disabling SSL verification can expose the 
 * connection to security risks, so use this only if absolutely necessary.
 * 
 * @package Gomax
 * @since 1.0.4
 */
if ( get_theme_mod( 'disables_ssl_verification' ) ) {
	add_filter( 'http_request_args', function( $args, $url ) {
		if ( strpos( $url, 'package.themeasy.co' ) !== false ) {
			$args['sslverify'] = false;
		}
		return $args;
	}, 10, 2);
}

/**
 * Main theme support functions.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_support() {

	// Textdomain
	load_theme_textdomain( 'gomax', get_template_directory() . '/languages' );

	// Nav menus
	register_nav_menus( array( 'menu-1' => esc_html__( 'Menu 1', 'gomax' ) ) );
	if ( gomax_has_core() ) {
		register_nav_menus( array( 'menu-2' => esc_html__( 'Menu 2', 'gomax' ) ) );
		register_nav_menus( array( 'menu-3' => esc_html__( 'Menu 3', 'gomax' ) ) );
		register_nav_menus( array( 'menu-4' => esc_html__( 'Menu 4', 'gomax' ) ) );
		register_nav_menus( array( 'menu-5' => esc_html__( 'Menu 5', 'gomax' ) ) );
		register_nav_menus( array( 'menu-6' => esc_html__( 'Menu 6', 'gomax' ) ) );
	}

	// Image resolutions to be automatically set in grids
	add_image_size( 'gomax_grid_2_cols', 800, 450, true );
	add_image_size( 'gomax_grid_3_cols', 535, 300, true );
	add_image_size( 'gomax_grid_4_cols', 400, 225, true );

	// Branding
	add_theme_support( 'custom-logo', array(
		'height'      => 100,
		'width'       => 400,
		'flex-width'  => true,
		'flex-height' => true,
	));
	
	// Posts
	add_theme_support( 'post-thumbnails' );

	// Elements
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	));

	// Needs
	add_theme_support( 'title-tag' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'responsive-embeds' );

	// Gutenberg
	add_theme_support( 'wp-block-styles' );

	// Customizer
	add_theme_support( 'align-wide' );
	add_theme_support( 'custom-header' );
	remove_theme_support( 'custom-header' );
	add_theme_support( 'custom-background' );
	remove_theme_support( 'custom-background' );
	add_theme_support( 'customize-selective-refresh-widgets' );

	// Editor
	add_editor_style( 'classic-editor.css' );
}
add_action( 'after_setup_theme', 'gomax_support', 10 );

/**
 * Customizes the WooCommerce gallery thumbnail size.
 * 
 * This function removes the default WooCommerce gallery thumbnail size
 * and registers a new size based on user-defined settings in the Customizer.
 * It ensures that the new size is applied during the 'init' action, 
 * allowing for proper integration with WooCommerce and other plugins.
 * 
 * The width and height are retrieved from the theme's Customizer settings,
 * providing flexibility for users to define their desired dimensions.
 * 
 * @package Gomax
 * @since 1.0.4
 */
function gomax_woocommerce_gallery_thumbnail_size() {
	// Remove default WooCommerce size before adding new one.
	remove_image_size( 'woocommerce_gallery_thumbnail' );

	// Get the size and height set in the customizer.
  $width = get_theme_mod( 'woocommerce_gallery_thumbnail_width', 140 );
  $height = get_theme_mod( 'woocommerce_gallery_thumbnail_height', 175 );
  add_image_size( 'woocommerce_gallery_thumbnail', $width, $height, true );
}
if ( gomax_has_woocommerce() ) {
	add_action( 'init', 'gomax_woocommerce_gallery_thumbnail_size', 10 );
}

/**
 * Set the pingback header reference.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_pingback_header() {	
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">', esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'gomax_pingback_header' );

/**
 * Website body opening action.
 * 
 * @package Gomax
 * @since 1.0.0
 */
if ( ! function_exists( 'wp_body_open' ) ) {
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
}

/**
 * Sidebar widget initiation.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_widgets_init() {

	register_sidebar(
		array(
			'name'          => esc_html__( 'Page Sidebar', 'gomax' ),
			'id'            => 'page-sidebar',
			'description'   => esc_html__( 'Widgets added here will be displayed in the sidebar of Single Pages. (The sidebar is only displayed in the Default Template).', 'gomax' ),
			'before_widget' => '<div id="%1$s" class="sidebar-block %2$s widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="title widget-title">',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Post Sidebar', 'gomax' ),
			'id'            => 'post-sidebar',
			'description'   => esc_html__( 'Widgets added here will be displayed in the sidebar of Single Posts. (The sidebar is only displayed in the Default Template).', 'gomax' ),
			'before_widget' => '<div id="%1$s" class="sidebar-block %2$s widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="title widget-title">',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Portfolio Sidebar', 'gomax' ),
			'id'            => 'portfolio-sidebar',
			'description'   => esc_html__( 'Widgets added here will be displayed in the sidebar of Single Portfolios. (The sidebar is only displayed in the Default Template).', 'gomax' ),
			'before_widget' => '<div id="%1$s" class="sidebar-block %2$s widget">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="title widget-title">',
			'after_title'   => '</h4>',
		)
	);

	if ( gomax_has_core() && gomax_has_woocommerce() ) {
		register_sidebar(
			array(
				'name'          => esc_html__( 'Shop Sidebar', 'gomax' ),
				'id'            => 'shop-sidebar',
				'description'   => esc_html__( 'Widgets added here will be displayed in the sidebar of WooCommerce Shop Page.', 'gomax' ),
				'before_widget' => '<div id="%1$s" class="sidebar-block %2$s widget">',
				'after_widget'  => '</div>',
				'before_title'  => '<h4 class="title widget-title">',
				'after_title'   => '</h4>',
			)
		);
	}
}
add_action( 'widgets_init', 'gomax_widgets_init' );

/**
 * Increases the big image size threshold value.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_big_image_size_threshold( $imagesize, $file, $attachment_id ) {
	return 3600;
}
add_filter( 'big_image_size_threshold', 'gomax_big_image_size_threshold', 10, 3 );

/**
 * Increases the excerpt threshold value.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_excerpt_length( $length ) {
  return 30;
}
add_filter( 'excerpt_length', 'gomax_excerpt_length', 999 );

/**
 * Modify the final text of the excerpt.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_excerpt_more( $more ) {
  return '...';
}
add_filter( 'excerpt_more', 'gomax_excerpt_more' );

/**
 * Customize the next post element.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_next_post_link( $format ) {
	$format = str_replace( 'href=', 'class="button next" href=', $format );
	return $format;
}
add_filter( 'next_post_link', 'gomax_next_post_link' );

/**
 * Customize the previous post element.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_previous_post_link( $format ) {
	$format = str_replace( 'href=', 'class="button prev" href=', $format );
	return $format;
}
add_filter( 'previous_post_link', 'gomax_previous_post_link' );

/**
 * Remove title prefix from file pages.
 * 
 * @package Gomax
 * @since 1.0.0
 */
add_filter( 'get_the_archive_title_prefix', '__return_false' );

/**
 * Function to register block styles.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_register_block_styles() {
	// Registering a new style for the "core/paragraph" block
	register_block_style(
		'core/paragraph', // The block name to which the style will be applied
		array(
			'name'  => 'highlight-paragraph', // The style identifier
			'label' => __( 'Highlighted Paragraph', 'gomax' ), // The visible name of the style
			'inline_style' => '.wp-block-paragraph.is-style-highlight-paragraph { background-color: yellow; }', // Custom styles
		)
	);
}
// Hook to load the block style during init
add_action('init', 'gomax_register_block_styles');

/**
 * Function to register block patterns.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_register_block_patterns() {
  // Registering a new block pattern
	register_block_pattern_category(
		'gomax_page',
		array(
			'label'       => _x( 'Pages', 'Block pattern category', 'gomax' ),
			'description' => __( 'A collection of full page layouts.', 'gomax' ),
		)
	);
}

// Hook to register block patterns during init
add_action('init', 'gomax_register_block_patterns');