<?php
/**
 * Queues style and script assets.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

/**
 * Theme function to queue styles.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_enqueue_style( $id, $file ) {
	wp_enqueue_style( $id, get_template_directory_uri() . $file, array(), gomax_get_theme_version() );
} 

/**
 * Theme function to queue scripts.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_enqueue_script( $id, $file ) {
	wp_enqueue_script( $id, get_template_directory_uri() . $file, array( 'jquery' ), gomax_get_theme_version(), true );
}

/**
 * This function adds a <link> tag in the <head> section of the site to preload
 * a custom font, improving performance by allowing the browser to load the font
 * early. The use of printf ensures that the font URL is correctly formatted.
 *
 * @package Gomax
 * @since 1.0.0
 */
function gomax_preload_font( $font_name, $font_url ) {
	$font_url = get_template_directory_uri() . $font_url;
	printf( "<link rel='preload' id='gomax-" . $font_name . "' href='%s' as='font' type='font/woff2' crossorigin='anonymous'>\n", esc_url( $font_url ) );
}

/**
 * Enqueues a custom font with rel="preload" at the top of the document.
 *
 * @package Gomax
 * @since 1.0.0
 */
function gomax_enqueue_fonts() {
	$preset = get_theme_mod( 'font_family_preset', '1' );
	// Preset 1
	if ( $preset == '1' ) {
		gomax_preload_font( 'lato-normal', '/assets/fonts/presets/Lato-Normal.woff2' );
		gomax_preload_font( 'lato-bold', '/assets/fonts/presets/Lato-Bold.woff2' );
		gomax_preload_font( 'neuehaas-normal', '/assets/fonts/presets/NeueHaas-Normal.woff2' ); 
		gomax_preload_font( 'neuehaas-bold', '/assets/fonts/presets/NeueHaas-Bold.woff2' );
	}
	// Preset 2
	if ( $preset == '2' ) {
		gomax_preload_font( 'lato-normal', '/assets/fonts/presets/Lato-Normal.woff2' );
		gomax_preload_font( 'lato-bold', '/assets/fonts/presets/Lato-Bold.woff2' );
		gomax_preload_font( 'circular-normal', '/assets/fonts/presets/Circular-Normal.woff2' ); 
		gomax_preload_font( 'circular-bold', '/assets/fonts/presets/Circular-Bold.woff2' );
	}
	// Preset 3
	if ( $preset == '3' ) {
		gomax_preload_font( 'roboto-normal', '/assets/fonts/presets/Roboto-Normal.woff2' );
		gomax_preload_font( 'roboto-bold', '/assets/fonts/presets/Roboto-Bold.woff2' );
		gomax_preload_font( 'larken-normal', '/assets/fonts/presets/Larken-Normal.woff2' ); 
		gomax_preload_font( 'larken-bold', '/assets/fonts/presets/Larken-Bold.woff2' );
	}
	// Icons
	gomax_preload_font( 'font-awesome', '/assets/fonts/font-awesome/fa-brands-400.woff2' );
	gomax_preload_font( 'font-awesome', '/assets/fonts/font-awesome/fa-regular-400.woff2' );
	gomax_preload_font( 'font-awesome', '/assets/fonts/font-awesome/fa-solid-900.woff2' );
}
add_action( 'wp_head', 'gomax_enqueue_fonts', 1 );

/**
 * Function for queuing main assets.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_enqueue_assets() {

	/**
	 * Vendor style.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	gomax_enqueue_style( 'gomax-menu-engine', '/assets/css/menu-engine.min.css' );
	gomax_enqueue_style( 'gomax-font-awesome', '/assets/css/vendor/font-awesome.min.css' );
	gomax_enqueue_style( 'gomax-bootstrap', '/assets/css/vendor/bootstrap.min.css' );
	gomax_enqueue_style( 'gomax-bricklayer', '/assets/css/vendor/bricklayer.min.css' );
	gomax_enqueue_style( 'gomax-swiper', '/assets/css/vendor/swiper.min.css' );
	gomax_enqueue_style( 'gomax-lightbox', '/assets/css/vendor/lightbox.min.css' );

	/**
	 * Main style.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	gomax_enqueue_style( 'gomax-main', '/style.css' );
	gomax_enqueue_style( 'gomax-core', '/assets/css/core.min.css' );

	/**
	 * Child theme style if active.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	if ( is_child_theme() ) {
		wp_enqueue_style( 'gomax-child-main', get_stylesheet_uri(), array(), gomax_get_theme_version());
	}
    
	/**
	 * Registers the default imagesloaded script and queues it.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	wp_enqueue_script( 'imagesloaded' );

	/**
	 * Registers the vendors script and queues it.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	gomax_enqueue_script( 'gomax-menu-engine', '/assets/js/menu-engine.min.js' );
	gomax_enqueue_script( 'gomax-bootstrap', '/assets/js/vendor/bootstrap.min.js' );
	gomax_enqueue_script( 'gomax-bricklayer', '/assets/js/vendor/bricklayer.min.js' );
	gomax_enqueue_script( 'gomax-swiper', '/assets/js/vendor/swiper.min.js' );
	gomax_enqueue_script( 'gomax-lightbox', '/assets/js/vendor/lightbox.min.js' );
	gomax_enqueue_script( 'gomax-shuffle', '/assets/js/vendor/shuffle.min.js' );
	gomax_enqueue_script( 'gomax-inview', '/assets/js/vendor/inview.min.js' );
	gomax_enqueue_script( 'gomax-typed', '/assets/js/vendor/typed.min.js' );
	gomax_enqueue_script( 'gomax-progressbar', '/assets/js/vendor/progressbar.min.js' );
	gomax_enqueue_script( 'gomax-gsap', '/assets/js/vendor/gsap.min.js' );
	gomax_enqueue_script( 'gomax-lax', '/assets/js/vendor/lax.min.js' );
	gomax_enqueue_script( 'gomax-magnetic', '/assets/js/vendor/magnetic.min.js' );

	/**
	 * Main script.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	gomax_enqueue_script( 'gomax-main', '/assets/js/core.min.js' );

	/**
	 * Child theme script if active.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	if ( is_child_theme() ) {
		wp_enqueue_script( 'gomax-child-main', str_replace( 'style.css', 'main.js', get_stylesheet_uri() ), array( 'jquery' ), gomax_get_theme_version(), true );
	}
}
add_action( 'wp_enqueue_scripts', 'gomax_enqueue_assets', 2 );

/**
 * Function for dequeue assets.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_dequeue_assets() {

	/**
	 * Dequeue Gutenberg block library.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	wp_dequeue_style( 'wp-block-library-theme' );
}
add_action( 'wp_enqueue_scripts', 'gomax_dequeue_assets', 10 );

/**
 * Function for queuing comment assets.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_enqueue_comment_assets() {

	/**
	 * WordPress script for comment reply.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	if ( ! is_admin() ) {
		if ( is_singular() && get_option( 'thread_comments' ) ) { 
			wp_enqueue_script( 'comment-reply' );
		}
  }
}
add_action( 'wp_enqueue_scripts', 'gomax_enqueue_comment_assets', 10 );

/**
 * Add inline scripts.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_enqueue_inline_script() {
	$inline_script = get_theme_mod( 'additional_js' );

	if ( $inline_script ) {		
		wp_add_inline_script( 'gomax-main', $inline_script, 'after' );
	}
}
add_action( 'wp_enqueue_scripts', 'gomax_enqueue_inline_script', 10 );

/**
 * Queue assets in admin head.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_enqueue_assets_admin() {
	wp_enqueue_style( 'gomax-admin', get_template_directory_uri() . '/assets/css/admin/admin.min.css', array(), gomax_get_theme_version());
	wp_enqueue_script( 'gomax-admin', get_template_directory_uri() . '/assets/js/admin/admin.min.js', array( 'jquery' ), gomax_get_theme_version(), 'in_footer' );
}
add_action( 'admin_init', 'gomax_enqueue_assets_admin' );